
//////////////////////////////////////////////////////////////////////////////////

// Module Name:    UART_TXD_Example 
// Target Devices: EP4CE6E22C8N
// Tool versions:  Quartus II 14.1
// Description: This example shows how to implement a UART transmitter on EP4CE6 Mini Board.
//              Hex data 0x55 will be sent to PC terminal when you press the start key(BTN1).
//              Use a serial port monitor software to view the result.
// UART Parameters: 19200 baudrate,8-bit data width, no parity check, 1 stop bit

//////////////////////////////////////////////////////////////////////////////////


module UART_TXD_Example( clk_50M, reset, start, tx_line );

input  wire clk_50M;
input  wire reset;
input  wire start;
output wire tx_line;

wire clk16x;

reg [23:0]  counter;



mod_m_counter #( .N(8), .M(161) ) baud_rate_gen	(	.clk(clk_50M),
																	.reset(reset),
																	.max_tick(clk16x),
																	.q()
																 );

uart_tx txd( .reset(reset), 
				 .clk16x(clk16x), 
				 .thr( 8'h55 ), 		 // Data 0xAA will be sent to PC terminal
				 .thr_wr_strobe(start), 
				 .databits(2'b11),    // 8 data bits
				 .stopbits(2'b01),    // 1 stop bit
				 .parity_en(1'b1),    // disable parity check
				 .parity_even(1'b0),  // ignored when parity check disabled
				 .parity_stick(1'b0), //ignore when parity check disabled
				 .sout(tx_line), 
				 .THRE(), 
				 .TXME()
			  );
																	  


endmodule
