`timescale 1ns / 1ps
//////////////////////////////////////////////////////////////////////////////////

// Module Name:    mod_m_counter 
// Target Devices: Sparatan 6 FPGA
// Tool versions: ISE WebPACK 14.1
// Description: This module is Mod-N counter. It can be used as a baudrate generator in UART transceiver controoller.

//////////////////////////////////////////////////////////////////////////////////
module mod_m_counter
#(
	parameter N = 4,
	parameter M = 10
 )
 (
	input  wire clk, reset,
	output wire max_tick,
	output wire [N-1:0] q
 );
 
reg [N-1:0] r_reg;
wire [N-1:0] r_next;
 
always@( posedge clk, posedge reset )
	if( reset )
		r_reg <= 0;
	else
		r_reg <= r_next;
		
assign r_next = ( r_reg == (M-1) ) ? 0 : r_reg + 1;

assign q = r_reg;

assign max_tick = ( r_reg == (M-1) ) ? 1'b1 : 1'b0;

endmodule
